# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django.contrib.auth.hashers import make_password
from pysnippets.strsnippets import strip

from account.models import AdministratorInfo, UserInfo


class UserInfoAdmin(admin.ModelAdmin):
    list_display = ('user_id', 'unionid', 'openid', 'nickname', 'sex', 'avatar', 'phone', 'country', 'province', 'city', 'status', 'created_at', 'updated_at')


class AdministratorInfoAdmin(admin.ModelAdmin):
    list_display = ('admin_id', 'admin_type', 'password', 'encryption', 'name', 'user_status', 'status', 'created_at', 'updated_at')
    list_filter = ('admin_type', 'user_status', 'status')
    readonly_fields = ('encryption',)

    def save_model(self, request, obj, form, change):
        obj.phone = strip(obj.name)
        obj.password = strip(obj.password)
        if obj.password:
            obj.encryption = make_password(obj.password, settings.MAKE_PASSWORD_SALT, settings.MAKE_PASSWORD_HASHER)
        obj.password = ''
        obj.save()


admin.site.register(UserInfo, UserInfoAdmin)
admin.site.register(AdministratorInfo, AdministratorInfoAdmin)
